| Title: | Repetitive Group Sampling Plan Based on Cpk |
|---|---|
| Description: | Functions to calculate Sample Number and Average Sample Number for Repetitive Group Sampling Plan Based on Cpk as given in Aslam et al. (2012) (<DOI:10.1080/00949655.2012.663374>). |
| Authors: | Muhammad Yaseen [aut, cre], Muhammad Aslam [aut, ctb], Sami Ullah [aut, ctb], Muhammad Kashif [aut, ctb] |
| Maintainer: | Muhammad Yaseen <[email protected]> |
| License: | GPL-2 |
| Version: | 0.2.0 |
| Built: | 2026-06-04 09:23:36 UTC |
| Source: | https://github.com/myaseen208/rgsp |
The rgsp package provides functionalities to calculate
Sample Number and Average Sample Number for a
Repetitive Group Sampling Plan based on Cpk as given in
Aslam et al. (2013).
Muhammad Yaseen ([email protected])
Muhammad Aslam ([email protected])
Sami Ullah ([email protected])
Muhammad Kashif ([email protected])
Aslam, M., Wu, C., Jun, C., Azam, M. and Itay, N. (2013). Developing a variables repetitive group sampling plan based on process capability index Cpk with unknown mean and variance. Journal of Statistical Computation and Simulation. 83(8):1507-1517. (https://www.tandfonline.com/doi/abs/10.1080/00949655.2012.663374)
Calculates Sample Number and Average Sample Number for Repetitive Group Sampling Plan based on Cpk under asymmetric case 1 as given in Aslam et al. (2013)
## Default S3 method: rgsp_asym1(.p1, .p2, .alpha, .beta, .nums, .rep)## Default S3 method: rgsp_asym1(.p1, .p2, .alpha, .beta, .nums, .rep)
.p1 |
Acceptable Quality Level (AQL) Probability |
.p2 |
Limiting Quality Level (LQL) Probability |
.alpha |
Producer's alpha-risk |
.beta |
Consumer's beta-risk |
.nums |
Number of samples with replacement at each iteration |
.rep |
Number of iterations |
Sample Number and Average Sample Number
Muhammad Yaseen ([email protected])
Muhammad Aslam ([email protected])
Sami Ullah ([email protected])
Muhammad Kashif ([email protected])
Aslam, M., Wu, C., Jun, C., Azam, M. and Itay, N. (2013). Developing a variables repetitive group sampling plan based on process capability index Cpk with unknown mean and variance. Journal of Statistical Computation and Simulation. 83(8):1507-1517. (https://www.tandfonline.com/doi/abs/10.1080/00949655.2012.663374)
rgsp_asym1( .p1 = 0.001 , .p2 = 0.003 , .alpha = 0.050 , .beta = 0.100 , .nums = 10000 , .rep = 10 # 1000 )rgsp_asym1( .p1 = 0.001 , .p2 = 0.003 , .alpha = 0.050 , .beta = 0.100 , .nums = 10000 , .rep = 10 # 1000 )
Calculates Sample Number and Average Sample Number for Repetitive Group Sampling Plan based on Cpk under asymmetric case 2 as given in Aslam et al. (2013)
## Default S3 method: rgsp_asym2(.p1, .p2, .alpha, .beta, .nums, .rep)## Default S3 method: rgsp_asym2(.p1, .p2, .alpha, .beta, .nums, .rep)
.p1 |
Acceptable Quality Level (AQL) Probability |
.p2 |
Limiting Quality Level (LQL) Probability |
.alpha |
Producer's alpha-risk |
.beta |
Consumer's beta-risk |
.nums |
Number of samples with replacement at each iteration |
.rep |
Number of iterations |
Sample Number and Average Sample Number
Muhammad Yaseen ([email protected])
Muhammad Aslam ([email protected])
Sami Ullah ([email protected])
Muhammad Kashif ([email protected])
Aslam, M., Wu, C., Jun, C., Azam, M. and Itay, N. (2013). Developing a variables repetitive group sampling plan based on process capability index Cpk with unknown mean and variance. Journal of Statistical Computation and Simulation. 83(8):1507-1517. (https://www.tandfonline.com/doi/abs/10.1080/00949655.2012.663374)
rgsp_asym2( .p1 = 0.001 , .p2 = 0.003 , .alpha = 0.050 , .beta = 0.100 , .nums = 10000 , .rep = 10 # 1000 )rgsp_asym2( .p1 = 0.001 , .p2 = 0.003 , .alpha = 0.050 , .beta = 0.100 , .nums = 10000 , .rep = 10 # 1000 )
Calculates Sample Number and Average Sample Number for Repetitive Group Sampling Plan based on Cpk under symmetric case as given in Aslam et al. (2013)
## Default S3 method: rgsp_sym(.p1, .p2, .alpha, .beta, .nums, .rep)## Default S3 method: rgsp_sym(.p1, .p2, .alpha, .beta, .nums, .rep)
.p1 |
Acceptable Quality Level (AQL) Probability |
.p2 |
Limiting Quality Level (LQL) Probability |
.alpha |
Producer's alpha-risk |
.beta |
Consumer's beta-risk |
.nums |
Number of samples with replacement at each iteration |
.rep |
Number of iterations |
Sample Number and Average Sample Number
Muhammad Yaseen ([email protected])
Muhammad Aslam ([email protected])
Sami Ullah ([email protected])
Muhammad Kashif ([email protected])
Aslam, M., Wu, C., Jun, C., Azam, M. and Itay, N. (2013). Developing a variables repetitive group sampling plan based on process capability index Cpk with unknown mean and variance. Journal of Statistical Computation and Simulation. 83(8):1507-1517. (https://www.tandfonline.com/doi/abs/10.1080/00949655.2012.663374)
rgsp_sym( .p1 = 0.0010 , .p2 = 0.0020 , .alpha = 0.0500 , .beta = 0.1000 , .nums = 10000 , .rep = 10 # 1000 )rgsp_sym( .p1 = 0.0010 , .p2 = 0.0020 , .alpha = 0.0500 , .beta = 0.1000 , .nums = 10000 , .rep = 10 # 1000 )